@@ -86,6 +86,8 @@
 
 K_EXPORT_PLASMA_APPLET(folderview, FolderView)
 
+Q_DECLARE_METATYPE(Qt::SortOrder)
+
 MimeModel::MimeModel(QObject *parent)
     : QStringListModel(parent)
 {
@@ -287,6 +289,27 @@ void RemoteWallpaperSetter::result(KJob *job)
 }
 
 
+// ---------------------------------------------------------------------------
+
+
+static QString sortOrderEnumToString(Qt::SortOrder order)
+{
+    if (order == Qt::AscendingOrder) {
+        return "ascending";
+    } else {
+        return "descending";
+    }
+}
+
+static Qt::SortOrder sortOrderStringToEnum(const QString& order)
+{
+    if (order == "ascending") {
+       return Qt::AscendingOrder;
+    } else {
+       return Qt::DescendingOrder;
+    }
+}
+
 
 // ---------------------------------------------------------------------------
 
@@ -363,6 +386,7 @@ void FolderView::init()
     m_customIconSize      = cg.readEntry("customIconSize", 0);
     m_sortDirsFirst       = cg.readEntry("sortDirsFirst", true);
     m_sortColumn          = cg.readEntry("sortColumn", int(KDirModel::Name));
+    m_sortOrder           = sortOrderStringToEnum(cg.readEntry("sortOrder", "ascending"));
     m_filterFiles         = cg.readEntry("filterFiles", "*");
     m_filterType          = cg.readEntry("filter", 0);
     m_filterFilesMimeList = cg.readEntry("mimeFilter", QStringList());
@@ -382,7 +406,7 @@ void FolderView::init()
     m_model->setFileNameFilter(m_filterFiles);
     m_model->setSortDirectoriesFirst(m_sortDirsFirst);
     m_model->setDynamicSortFilter(m_sortColumn != -1);
-    m_model->sort(m_sortColumn != -1 ? m_sortColumn : KDirModel::Name, Qt::AscendingOrder);
+    m_model->sort(m_sortColumn != -1 ? m_sortColumn : KDirModel::Name, m_sortOrder);
 
     m_dirLister = new DirLister(this);
     m_dirLister->setDelayedMimeTypes(true);
@@ -529,11 +553,13 @@ void FolderView::configChanged()
     }
 
     const int sortColumn = cg.readEntry("sortColumn", m_sortColumn);
-    if (m_sortColumn != sortColumn) {
+    const Qt::SortOrder sortOrder = sortOrderStringToEnum(cg.readEntry("sortOrder", sortOrderEnumToString(m_sortOrder)));
+    if ((m_sortColumn != sortColumn) || (m_sortOrder != m_sortOrder)) {
         m_sortColumn = sortColumn;
+        m_sortOrder = sortOrder;
         if (m_sortColumn != -1) {
             m_model->invalidate();
-            m_model->sort(m_sortColumn, Qt::AscendingOrder);
+            m_model->sort(m_sortColumn, m_sortOrder);
             m_model->setDynamicSortFilter(true);
         } else if (m_iconView) {
             m_iconView->setCustomLayout(true);
@@ -651,6 +677,10 @@ void FolderView::createConfigurationInterface(KConfigDialog *parent)
         uiLocation.showDesktopFolder->setChecked(true);
         uiLocation.placesCombo->setEnabled(false);
         uiLocation.lineEdit->setEnabled(false);
+    } else if (m_url == KUrl("activities:/current/")) {
+        uiLocation.showActivity->setChecked(true);
+        uiLocation.placesCombo->setEnabled(false);
+        uiLocation.lineEdit->setEnabled(false);
     } else {
         QModelIndex index;
         for (int i = 0; i < placesFilter->rowCount(); i++) {
@@ -694,7 +724,7 @@ void FolderView::createConfigurationInterface(KConfigDialog *parent)
 
     QString configTitleText = m_customLabel;
     if (m_customLabel.isEmpty() || m_customLabel == "___EMPTY___") {
-        configTitleText == i18n("None");
+        configTitleText = i18n("None");
     } else if (m_customLabel == "___DEFAULT___") {
         configTitleText = i18n("Default");
     } else if (m_customLabel == "___FULL___") {
@@ -811,6 +841,7 @@ void FolderView::createConfigurationInterface(KConfigDialog *parent)
     connect(uiFilter.filterFilesList->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)), parent, SLOT(settingsModified()));
 
     connect(uiLocation.showDesktopFolder, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
+    connect(uiLocation.showActivity, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(uiLocation.showPlace, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(uiLocation.showCustomFolder, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(uiLocation.placesCombo, SIGNAL(currentIndexChanged(int)), parent, SLOT(settingsModified()));
@@ -823,6 +854,8 @@ void FolderView::configAccepted()
 
     if (uiLocation.showDesktopFolder->isChecked()) {
         url = KUrl("desktop:/");
+    } else if (uiLocation.showActivity->isChecked()) {
+        url = KUrl("activities:/current/");
     } else if (uiLocation.showPlace->isChecked()) {
         PlacesFilterModel *filter = static_cast<PlacesFilterModel*>(uiLocation.placesCombo->model());
         KFilePlacesModel *model = static_cast<KFilePlacesModel*>(filter->sourceModel());
@@ -1285,11 +1318,9 @@ void FolderView::constraintsEvent(Plasma::Constraints constraints)
     if (constraints & Plasma::ScreenConstraint) {
         Plasma::Corona *c = corona();
         disconnect(c, SIGNAL(availableScreenRegionChanged()), this, SLOT(updateScreenRegion()));
-        if (isContainment()) {
-            if (screen() >= 0) {
-                updateScreenRegion();
-                connect(c, SIGNAL(availableScreenRegionChanged()), this, SLOT(updateScreenRegion()));
-            }
+        if (isContainment() && screen() > -1) {
+            updateScreenRegion();
+            connect(c, SIGNAL(availableScreenRegionChanged()), this, SLOT(updateScreenRegion()));
         }
     }
 }
@@ -1550,6 +1581,17 @@ void FolderView::createActions()
         sortByDate->setCheckable(true);
         sortByDate->setData(int(KDirModel::ModifiedTime));
 
+        m_sortingOrderGroup = new QActionGroup(this);
+        connect(m_sortingOrderGroup, SIGNAL(triggered(QAction*)), SLOT(sortingOrderChanged(QAction*)));
+        QAction *sortAscending = m_sortingOrderGroup->addAction(i18nc("Sort icons", "Ascending"));
+        QAction *sortDescending = m_sortingOrderGroup->addAction(i18nc("Sort icons", "Descending"));
+
+        sortAscending->setCheckable(true);
+        sortAscending->setData(QVariant::fromValue(Qt::AscendingOrder));
+
+        sortDescending->setCheckable(true);
+        sortDescending->setData(QVariant::fromValue(Qt::DescendingOrder));
+
         KAction *dirsFirst = new KAction(i18nc("Sort icons", "Folders First"), this);
         dirsFirst->setCheckable(true);
         dirsFirst->setChecked(m_sortDirsFirst);
@@ -1561,6 +1603,9 @@ void FolderView::createActions()
         sortMenu->addAction(sortByType);
         sortMenu->addAction(sortByDate);
         sortMenu->addSeparator();
+        sortMenu->addAction(sortAscending);
+        sortMenu->addAction(sortDescending);
+        sortMenu->addSeparator();
         sortMenu->addAction(dirsFirst);
 
         QMenu *iconsMenu = new QMenu;
@@ -1586,6 +1631,8 @@ void FolderView::createActions()
         m_actionCollection.addAction("sort_size", sortBySize);
         m_actionCollection.addAction("sort_type", sortByType);
         m_actionCollection.addAction("sort_date", sortByDate);
+        m_actionCollection.addAction("sort_ascending", sortAscending);
+        m_actionCollection.addAction("sort_descending", sortDescending);
 
         updateSortActionsState();
     }
@@ -1753,7 +1800,7 @@ void FolderView::toggleAlignToGrid(bool align)
 void FolderView::toggleClickToViewFolders(bool enable)
 {
    m_clickToView = enable;
-  
+
     if (m_iconView) {
         m_iconView->setClickToViewFolders(enable);
     }
@@ -1785,7 +1832,7 @@ void FolderView::sortingChanged(QAction *action)
 
     if (column != m_sortColumn) {
         m_model->invalidate();
-        m_model->sort(column, Qt::AscendingOrder);
+        m_model->sort(column, m_sortOrder);
         m_model->setDynamicSortFilter(true);
         m_sortColumn = column;
         config().writeEntry("sortColumn", m_sortColumn);
@@ -1794,11 +1841,29 @@ void FolderView::sortingChanged(QAction *action)
     }
 }
 
+void FolderView::sortingOrderChanged(QAction *action)
+{
+    const Qt::SortOrder order = action->data().value<Qt::SortOrder>();
+
+    if (order != m_sortOrder) {
+        m_model->invalidate();
+        m_model->sort(m_sortColumn, order);
+        m_model->setDynamicSortFilter(true);
+        m_sortOrder = order;
+        config().writeEntry("sortOrder", sortOrderEnumToString(m_sortOrder));
+        emit configNeedsSaving();
+        m_delayedSaveTimer.start(5000, this);
+    }
+}
+
 void FolderView::updateSortActionsState()
 {
     foreach (QAction *action, m_sortingGroup->actions()) {
         action->setChecked(action->data() == int(m_sortColumn));
     }
+    foreach (QAction *action, m_sortingOrderGroup->actions()) {
+        action->setChecked(action->data().value<Qt::SortOrder>() == m_sortOrder);
+    }
 }
 
 
